.. pyprika documentation master file, created by
   sphinx-quickstart on Sun Dec 29 13:07:53 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyprika's documentation!
===================================

Pyprika is a Python library for parsing and managing recipes. Its major
features are:

* Support for recognizing a human-friendly representations of quantities
  and measurements normally seen in cook books.
* Parsing a custom YAML spec for storing recipes on disk.
* A simple command line utility ``kit``, which makes use of the library for
  recipe management.

Contents:

.. toctree::
   :maxdepth: 2

   pyprika
   kit
   yaml-spec

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

